#
# spec file for package google-authenticator-libpam
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           google-authenticator-libpam
Version:        1.10
Release:        2.2
Summary:        Google Authenticator PAM module
License:        Apache-2.0
Group:          Productivity/Security
URL:            https://github.com/google/google-authenticator-libpam
Source:         %{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  libtool
BuildRequires:  pam-devel
# libqrencode.so.[234] are dynamically loaded if present in order to show a QR code
# As the library is not linked, it can't be auto-detected. And as it's not mandatory,
# we recommend it only
Recommends:     (libqrencode4 or libqrencode3 or libqrencode2)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Provides:       pam-google-authenticator = %{version}
Obsoletes:      pam-google-authenticator < %{version}

%description
Integrate GOOGLE Authenticator into your login process for full 2FA.

%prep
%setup -q

%build
./bootstrap.sh
%configure \
    --docdir=%{_docdir}/%{name} \
    --libdir=$(dirname %{_pam_moduledir})
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

%check
make test

%files
%defattr(-,root,root)
%doc CONTRIBUTING.md README.md totp.html FILEFORMAT
%license LICENSE
%{_pam_moduledir}/pam_google_authenticator.so
%{_bindir}/google-authenticator
%{_mandir}/man1/google-authenticator.1%{?ext_man}
%{_mandir}/man8/pam_google_authenticator.8%{?ext_man}

%changelog
* Wed Jul 24 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Migrate from tar_scm to obs_scm: be more storage efficient.
- Add tar service (buildtime) and change recompress from manual to
  buildtime: only generate tar.xz during build time to have valid
  .src.rpm.
* Thu Jul 18 2024 Jan Zerebecki <jan.suse@zerebecki.de>
- Recommend current qrencode version, instead of unavailable one
- Adapt to changing %%_pam_moduledir on different distributions
- Update to version 1.10:
  * Remove printing QR code using Google Charts URL
  * Fix utc-time for new everything
  * set variable 'buffer' that in base32_decode to unsigned integer type
  * Slight improvement in error message formatting
  * Update config file with grace periods in all cases
  * Fix comment on open_secret_file()
  * Exit with code 1 only if build-rpm fails
  * Double check the config size
  * Add more logging for config updates
  * Shorten syslog name to work with rsyslog
* Wed Apr 27 2022 Marcus Meissner <meissner@suse.com>
- added source url
* Tue Feb 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Properly install pam module to %%_pam_moduledir instead of
  /lib64/security (boo#1191035).
* Thu Dec  9 2021 rpm@fthiessen.de
- Update to version 1.09:
  * Fixed typo preventing use of setfsgid() over setegid()
  * Fixed regression getting maximum getpwnam buf size
  * set umask before `mkstemp`
  * Add `allow_readonly` option
  * Minor linter-level changes that probably don't matter
* Wed May 15 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to version 1.06:
  * More reliable temp file handling (#76)
  * Various improved logging in case of failures
  * Codes are now confirmed as part of setup (#104)
  * Optional grace period (#127)
- Changes from version 1.05:
  * Fix info leak when using nullok
  * Improve error messages
- Changes from version 1.04:
  * Add man pages
  * Fix "CWE-778: Insufficient Logging".
* Sat Mar 11 2017 sfalken@opensuse.org
- Explicitly package files installed by make install into _docdir:
  rpm 4.13 no longer implicitly packages those files.
* Mon Jan  9 2017 dimstar@opensuse.org
- Run the test suite (make test).
* Mon Jan  9 2017 dimstar@opensuse.org
- Recommend libqrencode3: the library is dynamically loaded if
  found in order to print qr codes (easier setup).
* Mon Jan  9 2017 dimstar@opensuse.org
- Initial package, version 1.03.
